#!/usr/bin/env python

"""Copy files for all 68k calcs

renamr68k.py [-p] [-t] [-z] [directory]

renamr68k is a Python script designed to be ran over a folder containing
a 68k project distribution. 

TIGCC and GCC4TI produce files that will run on all three 68k calculators,
the TI-89, the TI-92 Plus, and the Voyage 200. However, if a user only has
one of those calculators any accompanying text files will not be generated.
The same is true for program files- if you are releasing a TI-BASIC program
you will have to manually make copies for the other calculators.

Manually renaming the files can be annoying. This script will walk through
a build distribution directory and make copies of files so that all given
filetypes have both an *.89*, *.9x*, and *.v2*.

Program (*.**p), text (*.**t) and appvar (*.**y) files are supported. Use
the -p, -t, and -z switches to manually enable them in commandline mode.

This program can be double-clicked or ran from the commandline, it makes no
difference. But all supported filetypes will be used by double-clicking,
unlike in commandline mode where you must use switches to indicate which
types to use."""

import getopt
import os
import os.path
import shutil
import sys

def helpMsg():
	"""Print out the help text, then run the program."""
	print >> sys.stderr, __doc__
	raw_input()
	print ""
	directory = raw_input("Directory path: ")
	filetypes = ['p', 't', 'y']
	buildFiles(directory, filetypes)
	
def buildFiles(directory, filetypes):
	"""Walks through the directory and builds the files, as long as the third character of the extension is in filetypes."""
	calctypes = ['89', '9x', 'v2']
	count = 0
	
	#Verify the directory is valid
	if not os.path.exists(directory):
		print "The directory is invalid."
		return
	print "Directory verified, beginning process"
	
	#Walk through the directory
	for dirpath, dirnames, filenames in os.walk(directory):
		for file in filenames:
			fullname = os.path.join(dirpath, file)
			name, sep, type = file.partition('.')
			if len(type) != 3:
				continue
			calctype = type[:2]
			filetype = type[2]
			if ((filetype in filetypes) and (calctype in calctypes)):
				count += 1
				for calc in calctypes:
					if calctype != calc:
						newfile = name+sep+calc+filetype
						shutil.copyfile(fullname, os.path.join(dirpath, newfile))
	
	#Print number of files and return
	print ("Detected and worked on %d files" % (count))
	return
	
def main():
	"""The script function, handles all commandline stuff."""
	filetypes = []
	
	#Try to get opts and args from the commandline
	try:
		opts, args = getopt.getopt(sys.argv[1:], "pty", ["program", "text", "appvar"])
	except getopt.error, msg:
		pass
	
	#If we have no args, print help text before running- if we do, deal with them, and then run
	if ((len(opts) == 0) and (len(args) == 0)):
		helpMsg()
	else:
		for o, a in opts:
			if o in ('-p', '--program'):
				filetypes.append('p')
			elif o in ('-t', '--text'):
				filetypes.append('t')
			elif o in ('-z', '--appvar'):
				filetypes.append('y')
		for arg in args:
			buildFiles(arg, filetypes)

	#Pause for keypress (to enable executable mode!)
	raw_input()

if __name__ == "__main__":
	main()